@@ -68,7 +68,7 @@ def gettag(htmltag: str) -> str:
         if not _end < 0:
             _c = htmltag[(_beg + 1):_end]
     if _c != htmltag:
-        return chr(0x0020).join(strnorm(_c))
+        return chr(0x0020).join(strnorm(unescape(_c)))
     return unescape(htmltag)
 
 
